/**
 * \file   motors.h
 * \author    Pierluigi Rinaldi (p.rinaldi@comune.livorno.it
 * \version   V 0.1
 * \date   16 ottobre, 2013
 *
 * \brief  Driver pilotaggio motori PWM LAP.
 *
 * Funzioni di inizializzazione e pilotaggio motori in PWM LAP con PIC18F4431.
 * Il PIC opera con un clock a 40MHz (xtal 10MHz + PLL 4X)
 */

#ifndef _MOTORS_H
#define _MOTORS_H

#ifndef ENABLE
	#define ENABLE				1
	#define DISABLE				0
#endif

// errori
#define MOTOR_NUMBER_ERROR		1
#define MOTOR_PWR_ERROR			2

//Limita il massimo valore del DUTYcycle per evitare
//condizioni di PWM con DutyCycle >= 98%
#define PWM_LIMIT    2000    

// definizione motori
#define MOTOR_ALL					0
#ifndef MOTOR_1
	#define MOTOR_1					1
	#define MOTOR_2					2
#endif
 

// Valori di PTPER per le frequenze di lavoro piu' comuni
#define PWM_10K        		0x03ff
#define PWM_20K        		0x01ff
#define PWM_40K        		0x00ff

#ifndef EN_MOT1
	#define EN_MOT1 LATEbits.LATE0   /* Enable del motore 1 led verde */
	#define EN_MOT2 LATEbits.LATE1   /* Enable del motore 2 led giallo */
	#define EN_MOT3 LATEbits.LATE2   /* Enable del led rosso */
#endif

/*!
 * \brief Inizializza PWM e HW per pilotaggio motori
 *
 * [Imposta il power timer control,
	PIN di output (RB0-RB1 e RB2-RB3),
	Override e Fault]
 *
 * \param[in] [period] [frequenza PWM]
 * \return [void]
 * \sa []
 * \note []
 * \warning []
 */
void initMotors (unsigned int period);

/*!
 * \brief pilota motori PWM e HW
 *
 * [Abilita/disabilta motori,
	normalizza (+/-2048) il duty cycle,
	lo applica ai motori]
 *
 * \param[in] [motor, enable, dc] [motor sceglie il motore oppure ambedue, 
	enable abilita o sisabilita,
	dc passa il dutycicle range +/- 2048]
 * \return [rc = 0 good, rc = 1 errato indirizzo motore, rc = 2 valore pwm oltre pwm_max]
 * \sa []
 * \note []
 * \warning []
 */
unsigned char setMotor(unsigned char motor,unsigned char enable,int dc);



#endif
