/**
 * \file   ninja01.c
 * \author    Pierluigi Rinaldi (p.rinaldi@comune.livorno.it
 * \version   V 0.1
 * \date   16 ottobre, 2013
 *
 * \brief  Programma di test x pilotaggio motori PWM LAP.
 * \details Utilizza PIC18F4431.
 * 	Il PIC opera con un clock a 40MHz (xtal 10MHz + PLL 4X).
 * 	Il programma di test imposta i motori con una frequenza di PWM di 20KHz
 * 	Abilita gli Enable
 * 	Imposta il motore 1 con Duty Cycle al 50%
 * 	Imposta il motore 2 con Duty Cicle tra il 2% ed il 98%
 */
#include <p18f4431.h>
#include <delays.h>

#include "motors.h"

#pragma config OSC  	= HSPLL  	// Oscillatore PLL 4x attivo
#pragma config WDTEN 	= OFF  		// Whatch dog disattivato
#pragma config PWRTEN 	= ON  		// Power UP timer abilitato
#pragma config LVP  	= OFF  		// Programmazione LVP disabilitata
#pragma config BOREN 	= OFF  		// Brown out Reset disabilitato
#pragma config BORV  	= 42  		// Tensione per Brown out Reset 4.2 Volt
#pragma config PWM4MX 	= RB5		// RB5 = PWM4

void initHW(void);

void main(void){
	int duty = 0;
	char rc = 1;
	
	initHW();
	initMotors(PWM_20K);
	setMotor(1, ENABLE, 0);
	setMotor(2, ENABLE, 0);
	Delay10KTCYx( 255 ); 
	  
	while(1){
		if (rc != 0)duty = -PWM_LIMIT;
		rc = setMotor(2, ENABLE, duty ++);
		EN_MOT3 = !EN_MOT3;
		Delay1KTCYx( 20 );   
		
	};
	return;
}

void initHW(void){
	
// PINs Direction
	TRISA = 0b11111111;		// Ananlogs and Encoder
	TRISB = 0b11000000;		// uscite PWM e ICSP
	TRISC = 0b10111001;		// I2C, RS232, pwm
	TRISD = 0x00000000;		// display lcd
	TRISE = 0x11110000;		// led

// PINs Initial State
	PORTA = 0x11111111;
	PORTB = 0x00000000;
	PORTC = 0x00000000;
	PORTD = 0x00000000;
	PORTE = 0x00000000;
	INTCON  = 0;     		// Clear Interrupt
	return;
}
